import * as Name from "./Name";
/**
 * ユーザーが利用できる各種変換オプション
 */
export const create = () => {
    const convertReservedWord = (word) => {
        if (["import", "export"].includes(word)) {
            return word + "_";
        }
        return word;
    };
    const convertString = (text) => {
        if (Name.isAvailableVariableName(text)) {
            return text;
        }
        return text.replace(/-/g, "$").replace(/\//g, "$");
    };
    return {
        escapeOperationIdText: (operationId) => {
            return convertString(operationId);
        },
        escapeDeclarationText: (text) => {
            return convertReservedWord(convertString(text));
        },
        escapePropertySignatureName: (text) => {
            return Name.escapeText(text);
        },
        escapeTypeReferenceNodeName: (text) => {
            return convertString(text);
        },
        generateResponseName: (operationId, statusCode) => {
            return Name.responseName(convertString(operationId), statusCode);
        },
        generateArgumentParamsTypeDeclaration: (operationId) => {
            return Name.argumentParamsTypeDeclaration(convertString(operationId));
        },
        generateRequestContentTypeName: (operationId) => {
            return Name.requestContentType(convertString(operationId));
        },
        generateResponseContentTypeName: (operationId) => {
            return Name.responseContentType(convertString(operationId));
        },
        generateParameterName: (operationId) => {
            return Name.parameterName(convertString(operationId));
        },
        generateRequestBodyName: (operationId) => {
            return Name.requestBodyName(convertString(operationId));
        },
        generateFunctionName: (operationId) => {
            return convertString(operationId);
        },
    };
};
//# sourceMappingURL=ConverterContext.js.map