import * as CallRequest from "./CallRequest";
import * as HeaderParameter from "./HeaderParameter";
import * as PathParameter from "./PathParameter";
import * as QueryParameter from "./QueryParameter";
export const create = (factory, params) => {
    const statements = [];
    const { pickedParameters } = params;
    // Generate Path Parameter
    const pathParameters = pickedParameters.filter(PathParameter.isPathParameter);
    statements.push(PathParameter.create(factory, params.rawRequestUri, pathParameters));
    const initialHeaderObject = {};
    if (params.has2OrMoreRequestContentTypes) {
        initialHeaderObject["Content-Type"] = {
            type: "variable",
            value: `params.headers.Content-Type`,
        };
    }
    else if (params.requestFirstContentType) {
        initialHeaderObject["Content-Type"] = {
            type: "string",
            value: params.requestFirstContentType,
        };
    }
    if (params.has2OrMoreSuccessResponseContentTypes) {
        initialHeaderObject["Accept"] = {
            type: "variable",
            value: `params.headers.Accept`,
        };
    }
    else if (params.successResponseFirstContentType) {
        initialHeaderObject["Accept"] = {
            type: "string",
            value: params.successResponseFirstContentType,
        };
    }
    // Generate Header Parameter
    const headerParameter = pickedParameters.filter(item => item.in === "header");
    const headerObject = Object.values(headerParameter).reduce((previous, current) => {
        return { ...previous, [current.name]: { type: "variable", value: `params.parameter.${current.name}` } };
    }, initialHeaderObject);
    statements.push(HeaderParameter.create(factory, {
        variableName: "headers",
        object: headerObject,
    }));
    // Generate Query Parameter
    if (params.hasQueryParameters) {
        const queryParameter = pickedParameters.filter(item => item.in === "query");
        const queryObject = Object.values(queryParameter).reduce((previous, current) => {
            return {
                ...previous,
                [current.name]: { type: "variable", value: `params.parameter.${current.name}`, style: current.style, explode: !!current.explode },
            };
        }, {});
        statements.push(QueryParameter.create(factory, { variableName: "queryParameters", object: queryObject }));
    }
    // Generate CallRequest
    statements.push(factory.ReturnStatement.create({
        expression: CallRequest.create(factory, params),
    }));
    return statements.length == 0 ? [factory.ReturnStatement.create({})] : statements;
};
//# sourceMappingURL=index.js.map