import { Def } from "../store";
import { OpenApi } from "../types";
export declare type LocalReferencePattern = "#/components/schemas/" | "#/components/responses/" | "#/components/parameters/" | "#/components/examples/" | "#/components/requestBodies/" | "#/components/headers/" | "#/components/securitySchemes/" | "#/components/links/" | "#/components/callbacks/" | "#/components/pathItems/";
export interface LocalReference {
    type: "local";
    /**
     * @example #/components/schemas/Hoge -> Hoge
     */
    name: string;
    /**
     * startsWith `components`
     * components/headers/hoge/fuga
     */
    path: string;
}
export interface RemoteReference<T> {
    type: "remote";
    /**
     * file path
     */
    referencePoint: string;
    /**
     * startsWith `components`
     * components/headers/hoge/fuga
     */
    path: string;
    /**
     * From filename - extension
     * @example a/b/c/Hoge.yml -> Hoge
     */
    name: string;
    /**
     * If "componentName" exists, you can create an alias for the type.
     * If it does not exist, you need to define the type directly.
     */
    componentName?: Def.ComponentName;
    data: T;
}
export declare type Type<T> = LocalReference | RemoteReference<T>;
export declare const localReferenceComponents: {
    readonly "#/components/schemas/": "components/schemas";
    readonly "#/components/responses/": "components/responses";
    readonly "#/components/parameters/": "components/parameters";
    readonly "#/components/examples/": "components/examples";
    readonly "#/components/requestBodies/": "components/requestBodies";
    readonly "#/components/headers/": "components/headers";
    readonly "#/components/securitySchemes/": "components/securitySchemes";
    readonly "#/components/links/": "components/links";
    readonly "#/components/callbacks/": "components/callbacks";
    readonly "#/components/pathItems/": "components/pathItems";
};
export declare const getLocalReferencePattern: (reference: OpenApi.Reference) => "#/components/schemas/" | "#/components/responses/" | "#/components/parameters/" | "#/components/examples/" | "#/components/requestBodies/" | "#/components/headers/" | "#/components/securitySchemes/" | "#/components/links/" | "#/components/callbacks/" | "#/components/pathItems/" | undefined;
export declare const generateLocalReference: (reference: OpenApi.Reference) => LocalReference | undefined;
export declare const generateReferencePoint: (currentPoint: string, reference: OpenApi.Reference) => string;
export declare const generate: <T>(entryPoint: string, currentPoint: string, reference: OpenApi.Reference) => Type<T>;
export declare const resolveRemoteReference: (entryPoint: string, currentPoint: string, reference: OpenApi.Reference) => {
    referencePoint: string;
    data: any;
};
export declare const resolveLocalReference: (entryPoint: string, currentPoint: string, reference: OpenApi.Reference) => any;
